@@ -24,10 +24,10 @@
 #include "giggle-rev-list-view.h"
 #include "giggle-revision-view.h"
 #include "giggle-view-diff.h"
-#include "giggle-view-shell.h"
 
 #include <libgiggle/giggle-history.h>
 #include <libgiggle/giggle-searchable.h>
+#include <libgiggle/giggle-view-shell.h>
 
 #include <libgiggle-git/giggle-git.h>
 #include <libgiggle-git/giggle-git-diff.h>
@@ -45,8 +45,6 @@
 #define GIGGLE_IS_VIEW_HISTORY_SNAPSHOT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GIGGLE_TYPE_VIEW_HISTORY_SNAPSHOT))
 #define GIGGLE_VIEW_HISTORY_SNAPSHOT_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), GIGGLE_TYPE_VIEW_HISTORY_SNAPSHOT, GiggleViewHistorySnapshotClass))
 
-#define GET_PRIV(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), GIGGLE_TYPE_VIEW_HISTORY, GiggleViewHistoryPriv))
-
 enum {
 	PROP_0,
 	PROP_UI_MANAGER,
@@ -57,7 +55,7 @@ enum {
 	REVISION_NUM_COLS
 };
 
-typedef struct {
+struct _GiggleViewHistoryPriv {
 	GtkWidget               *main_vpaned;
 	GtkWidget               *revision_shell;
 	GtkWidget               *view_diff;
@@ -72,7 +70,7 @@ typedef struct {
 	GiggleGitConfig         *configuration;
 
 	guint                    selection_changed_idle;
-} GiggleViewHistoryPriv;
+};
 
 typedef struct {
 	GObject              parent;
@@ -117,7 +115,7 @@ view_history_get_property (GObject      *object,
 {
 	GiggleViewHistoryPriv *priv;
 
-	priv = GET_PRIV (object);
+	priv = GIGGLE_VIEW_HISTORY (object)->priv;
 
 	switch (param_id) {
 	case PROP_UI_MANAGER:
@@ -137,7 +135,7 @@ view_history_set_property (GObject      *object,
 {
 	GiggleViewHistoryPriv *priv;
 
-	priv = GET_PRIV (object);
+	priv = GIGGLE_VIEW_HISTORY (object)->priv;
 
 	switch (param_id) {
 	case PROP_UI_MANAGER:
@@ -156,7 +154,7 @@ view_history_finalize (GObject *object)
 {
 	GiggleViewHistoryPriv *priv;
 
-	priv = GET_PRIV (object);
+	priv = GIGGLE_VIEW_HISTORY (object)->priv;
 
 	if (priv->job) {
 		giggle_git_cancel_job (priv->git, priv->job);
@@ -181,17 +179,23 @@ view_history_set_busy (GtkWidget *widget,
 		       gboolean   busy)
 {
 	GdkCursor *cursor;
+	GdkWindow *window;
 
-	if (!GTK_WIDGET_REALIZED (widget)) {
+#if GTK_CHECK_VERSION (2,19,5)
+	if (!gtk_widget_get_realized (widget))
+#else
+	if (!GTK_WIDGET_REALIZED (widget))
+#endif
 		return;
-	}
+
+	window = gtk_widget_get_window (widget);
 
 	if (busy) {
 		cursor = gdk_cursor_new (GDK_WATCH);
-		gdk_window_set_cursor (widget->window, cursor);
+		gdk_window_set_cursor (window, cursor);
 		gdk_cursor_unref (cursor);
 	} else {
-		gdk_window_set_cursor (widget->window, NULL);
+		gdk_window_set_cursor (window, NULL);
 	}
 }
 
@@ -238,7 +242,7 @@ view_history_get_branches_cb (GiggleGit    *git,
 	gboolean               changed;
 
 	view = GIGGLE_VIEW_HISTORY (user_data);
-	priv = GET_PRIV (view);
+	priv = view->priv;
 
 	if (error) {
 		GtkWidget *dialog;
@@ -298,7 +302,7 @@ view_history_diff_current_cb (GiggleGit *git,
 	GtkTreeIter            iter;
 	const gchar           *text;
 
-	priv = GET_PRIV (user_data);
+	priv = GIGGLE_VIEW_HISTORY (user_data)->priv;
 
 	/* FIXME: error report missing */
 	if (error) {
@@ -333,7 +337,7 @@ view_history_get_revisions_cb (GiggleGit    *git,
 	GList                 *revisions;
 
 	view = GIGGLE_VIEW_HISTORY (user_data);
-	priv = GET_PRIV (view);
+	priv = view->priv;
 
 	if (error) {
 		GtkWidget *dialog;
@@ -397,7 +401,7 @@ view_history_update_revisions (GiggleViewHistory  *view)
 {
 	GiggleViewHistoryPriv *priv;
 
-	priv = GET_PRIV (view);
+	priv = view->priv;
 
 	view_history_set_busy (GTK_WIDGET (priv->revision_list), TRUE);
 	giggle_rev_list_view_set_model (GIGGLE_REV_LIST_VIEW (priv->revision_list), NULL);
@@ -421,7 +425,7 @@ view_history_git_dir_notify (GiggleViewHistory *view)
 {
 	GiggleViewHistoryPriv *priv;
 
-	priv = GET_PRIV (view);
+	priv = view->priv;
 
 	view_history_update_revisions (view);
 
@@ -441,7 +445,7 @@ view_history_idle_cb (gpointer data)
 {
 	GiggleViewHistoryPriv *priv;
 
-	priv = GET_PRIV (data);
+	priv = GIGGLE_VIEW_HISTORY (data)->priv;
 
 	giggle_git_config_bind (priv->configuration,
 				GIGGLE_GIT_CONFIG_FIELD_HISTORY_VIEW_VPANE_POSITION,
@@ -457,7 +461,8 @@ view_history_selection_changed_idle (gpointer user_data)
 	GiggleViewHistoryPriv        *priv;
 	GList                        *files;
 
-	priv = GET_PRIV (data->view);
+	priv = GIGGLE_VIEW_HISTORY (data->view)->priv;
+
 	files = NULL;
 
 	giggle_view_diff_set_revisions (GIGGLE_VIEW_DIFF (priv->view_diff),
@@ -475,7 +480,7 @@ view_history_revision_list_selection_changed_cb (GiggleRevListView *list,
 	GiggleViewHistoryPriv        *priv;
 	ViewHistorySelectionIdleData *data;
 
-	priv = GET_PRIV (view);
+	priv = view->priv;
 
 	giggle_revision_view_set_revision (
 		GIGGLE_REVISION_VIEW (priv->revision_view), revision1);
@@ -501,11 +506,15 @@ view_history_revision_list_key_press_cb (GiggleRevListView *list,
 					 GdkEventKey        *event,
 					 GiggleViewHistory  *view)
 {
-	GiggleViewHistoryPriv *priv = GET_PRIV (view);
+	GiggleViewHistoryPriv *priv;
 	GtkTreePath           *path, *start, *end;
 	GtkTreeSelection      *selection;
 	GtkAdjustment         *adj;
 	gdouble                value;
+	gdouble                adj_value;
+	gdouble                page_size;
+
+	priv = view->priv;
 
 	if (event->keyval != GDK_space && event->keyval != GDK_BackSpace)
 		return FALSE;
@@ -513,12 +522,15 @@ view_history_revision_list_key_press_cb (GiggleRevListView *list,
 	giggle_view_shell_set_view_name (GIGGLE_VIEW_SHELL (priv->revision_shell), "DiffView");
 	adj = gtk_scrolled_window_get_vadjustment (GTK_SCROLLED_WINDOW (priv->revision_list_sw));
 
-	value = event->keyval == GDK_space ?
-		adj->value + (adj->page_size * 0.8) :
-		adj->value - (adj->page_size * 0.8);
+	adj_value = gtk_adjustment_get_value (adj);
+	page_size = gtk_adjustment_get_page_size (adj);
 
-	value = CLAMP (value, adj->lower, adj->upper - adj->page_size);
-	g_object_set (adj, "value", value, NULL);
+	value = event->keyval == GDK_space ?
+		adj_value + (page_size * 0.8) :
+		adj_value - (page_size * 0.8);
+
+	value = CLAMP (value, gtk_adjustment_get_lower (adj), gtk_adjustment_get_upper (adj) - page_size);
+	gtk_adjustment_set_value (adj, value);
 
 	if (gtk_tree_view_get_visible_range (GTK_TREE_VIEW (priv->revision_list), &start, &end)) {
 		selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (priv->revision_list));
@@ -542,7 +554,7 @@ view_history_setup_revision_list (GObject *object)
 {
 	GiggleViewHistoryPriv *priv;
 
-	priv = GET_PRIV (object);
+	priv = GIGGLE_VIEW_HISTORY (object)->priv;
 
 	priv->revision_list_sw = gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (priv->revision_list_sw),
@@ -570,7 +582,7 @@ view_history_setup_revision_pane (GObject *object)
 	GtkWidget             *vbox;
 	GtkWidget	      *toolbar;
 
-	priv = GET_PRIV (object);
+	priv = GIGGLE_VIEW_HISTORY (object)->priv;
 
 	gtk_rc_parse_string ("style \"view-history-toolbar-style\" {"
 			     "  GtkToolbar::shadow-type = none"
@@ -588,7 +600,7 @@ view_history_setup_revision_pane (GObject *object)
 
 	vbox = gtk_vbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (vbox), toolbar, FALSE, TRUE, 0);
-	gtk_box_pack_start_defaults (GTK_BOX (vbox), priv->revision_shell);
+	gtk_box_pack_start (GTK_BOX (vbox), priv->revision_shell, TRUE, TRUE, 0);
 	gtk_paned_pack2 (GTK_PANED (priv->main_vpaned), vbox, FALSE, FALSE);
 	gtk_widget_show_all (vbox);
 
@@ -608,7 +620,7 @@ view_history_constructed (GObject *object)
 {
 	GiggleViewHistoryPriv *priv;
 
-	priv = GET_PRIV (object);
+	priv = GIGGLE_VIEW_HISTORY (object)->priv;
 
 	/* git interaction */
 	priv->git = giggle_git_get ();
@@ -666,7 +678,7 @@ view_history_search (GiggleSearchable      *searchable,
 {
 	GiggleViewHistoryPriv *priv;
 
-	priv = GET_PRIV (searchable);
+	priv = GIGGLE_VIEW_HISTORY (searchable)->priv;
 
 	if (!giggle_searchable_search (GIGGLE_SEARCHABLE (priv->revision_list),
 				       search_term, direction, full_search)) {
@@ -696,7 +708,7 @@ view_history_cancel_search (GiggleSearchable *searchable)
 {
 	GiggleViewHistoryPriv *priv;
 
-	priv = GET_PRIV (searchable);
+	priv = GIGGLE_VIEW_HISTORY (searchable)->priv;
 
 	giggle_searchable_cancel (GIGGLE_SEARCHABLE (priv->revision_list));
 }
@@ -748,7 +760,7 @@ giggle_view_history_snapshot_class_init (GiggleViewHistorySnapshotClass *class)
 static GObject *
 view_history_capture (GiggleHistory *history)
 {
-	GiggleViewHistoryPriv     *priv = GET_PRIV (history);
+	GiggleViewHistoryPriv     *priv;
 	GiggleViewHistorySnapshot *snapshot;
 	GtkTreeRowReference       *reference;
 	GtkTreeSelection          *selection;
@@ -757,6 +769,8 @@ view_history_capture (GiggleHistory *history)
 	GtkTreePath               *path;
 	GList                     *l;
 
+	priv = GIGGLE_VIEW_HISTORY (history)->priv;
+
 	snapshot = g_object_new (GIGGLE_TYPE_VIEW_HISTORY_SNAPSHOT, NULL);
 
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (priv->revision_list));
@@ -785,13 +799,16 @@ static void
 view_history_restore (GiggleHistory *history,
 		      GObject       *object)
 {
-	GiggleViewHistoryPriv     *priv = GET_PRIV (history);
+	GiggleViewHistoryPriv     *priv;
 	GtkTreeSelection          *selection;
 	GiggleViewHistorySnapshot *snapshot;
 	GtkTreePath               *path;
 	GList                     *l;
 
 	g_return_if_fail (GIGGLE_IS_VIEW_HISTORY_SNAPSHOT (object));
+
+	priv = GIGGLE_VIEW_HISTORY (history)->priv;
+
 	snapshot = GIGGLE_VIEW_HISTORY_SNAPSHOT (object);
 
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (priv->revision_list));
@@ -820,6 +837,9 @@ giggle_view_history_history_init (GiggleHistoryIface *iface)
 static void
 giggle_view_history_init (GiggleViewHistory *view)
 {
+	view->priv = G_TYPE_INSTANCE_GET_PRIVATE (view,
+	                                          GIGGLE_TYPE_VIEW_HISTORY,
+	                                          GiggleViewHistoryPriv);
 }
 
 GtkWidget *
@@ -849,7 +869,7 @@ giggle_view_history_set_graph_visible (GiggleViewHistory *view,
 
 	g_return_if_fail (GIGGLE_IS_VIEW_HISTORY (view));
 
-	priv = GET_PRIV (view);
+	priv = view->priv;
 
 	giggle_rev_list_view_set_graph_visible (
 		GIGGLE_REV_LIST_VIEW (priv->revision_list), visible);
@@ -866,7 +886,7 @@ giggle_view_history_select (GiggleViewHistory *view,
 	g_return_val_if_fail (GIGGLE_IS_VIEW_HISTORY (view), FALSE);
 	g_return_val_if_fail (GIGGLE_IS_REVISION (revision) || !revision, FALSE);
 
-	priv = GET_PRIV (view);
+	priv = view->priv;
 
 	selection = g_list_prepend (NULL, revision);
 	count = giggle_rev_list_view_set_selection (GIGGLE_REV_LIST_VIEW (priv->revision_list), selection);
