@@ -28,13 +28,13 @@
 #include "giggle-helpers.h"
 #include "giggle-view-file.h"
 #include "giggle-view-history.h"
-#include "giggle-view-shell.h"
 #include "giggle-view-summary.h"
 
 #include <libgiggle/giggle-clipboard.h>
 #include <libgiggle/giggle-history.h>
 #include <libgiggle/giggle-plugin-manager.h>
 #include <libgiggle/giggle-searchable.h>
+#include <libgiggle/giggle-view-shell.h>
 
 #include <libgiggle-git/giggle-git-config.h>
 
@@ -46,9 +46,7 @@
 #include <string.h>
 #include <stdlib.h>
 
-#define GET_PRIV(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), GIGGLE_TYPE_WINDOW, GiggleWindowPriv))
 
-#define RECENT_FILES_GROUP		"giggle"
 #define RECENT_REPOS_PLACEHOLDER_PATH	"/ui/MainMenubar/ProjectMenu/RecentRepositories"
 
 #define HISTORY_GO_BACK_PATH		"/ui/MainToolbar/HistoryGoBack"
@@ -71,7 +69,8 @@ enum {
 	SEARCH_PREV
 };
 
-typedef struct {
+struct _GiggleWindowPriv
+{
 	/* Model */
 	GiggleGit           *git;
 	GiggleGitConfig     *configuration;
@@ -111,7 +110,7 @@ typedef struct {
 
 	GList               *history;
 	guint                history_locked;
-} GiggleWindowPriv;
+};
 
 typedef struct {
 	GiggleView *view;
@@ -144,10 +143,12 @@ window_history_list_free (GList *list)
 static void
 window_history_update_ui (GiggleWindow *window)
 {
-	GiggleWindowPriv *priv = GET_PRIV (window);
+	GiggleWindowPriv *priv;
 	gboolean          back = FALSE, forward = FALSE;
 	GtkAction        *action;
 
+	priv = window->priv;
+
 	if (!priv->ui_manager)
 		return;
 
@@ -166,9 +167,11 @@ window_history_update_ui (GiggleWindow *window)
 static void
 window_history_reset (GiggleWindow *window)
 {
-	GiggleWindowPriv *priv = GET_PRIV (window);
+	GiggleWindowPriv *priv;
 	GList            *head;
 
+	priv = window->priv;
+
 	head = g_list_first (priv->history);
 	window_history_list_free (head);
 	priv->history = NULL;
@@ -186,9 +189,11 @@ window_history_remove_view (GiggleWindow *window,
 static void
 window_history_capture (GiggleWindow *window)
 {
-	GiggleWindowPriv     *priv = GET_PRIV (window);
+	GiggleWindowPriv     *priv;
 	GiggleWindowSnapshot *snapshot;
 
+	priv = window->priv;
+
 	if (priv->history_locked)
 		return;
 
@@ -217,7 +222,9 @@ static void
 window_history_restore_snapshot (GiggleWindow         *window,
 				 GiggleWindowSnapshot *snapshot)
 {
-	GiggleWindowPriv *priv = GET_PRIV (window);
+	GiggleWindowPriv *priv;
+
+	priv = window->priv;
 
 	if (priv->history_locked)
 		return;
@@ -240,8 +247,11 @@ window_history_restore_snapshot (GiggleWindow         *window,
 static void
 window_dispose (GObject *object)
 {
-	GiggleWindow     *window = GIGGLE_WINDOW (object);
-	GiggleWindowPriv *priv = GET_PRIV (window);
+	GiggleWindow     *window;
+	GiggleWindowPriv *priv;
+
+	window = GIGGLE_WINDOW (object);
+	priv = window->priv;
 
 	if (priv->view_shell) {
 		while (gtk_notebook_get_n_pages (GTK_NOTEBOOK (priv->view_shell)))
@@ -311,12 +321,12 @@ window_save_state (GiggleWindow *window)
 	char              geometry[25];
 	gboolean          maximized;
 
-	priv = GET_PRIV (window);
+	priv = window->priv;
 
 	g_snprintf (geometry, sizeof (geometry), "%dx%d+%d+%d",
 		    priv->width, priv->height, priv->x, priv->y);
 
-	maximized = gdk_window_get_state (GTK_WIDGET (window)->window) & GDK_WINDOW_STATE_MAXIMIZED;
+	maximized = gdk_window_get_state (gtk_widget_get_window (GTK_WIDGET (window))) & GDK_WINDOW_STATE_MAXIMIZED;
 
 	giggle_git_config_set_field (priv->configuration,
 				     GIGGLE_GIT_CONFIG_FIELD_MAIN_WINDOW_GEOMETRY,
@@ -335,9 +345,11 @@ static gboolean
 window_configure_event (GtkWidget         *widget,
 			GdkEventConfigure *event)
 {
-	GiggleWindowPriv *priv = GET_PRIV (widget);
+	GiggleWindowPriv *priv;
 
-	if (!(gdk_window_get_state (widget->window) & GDK_WINDOW_STATE_MAXIMIZED)) {
+	priv = GIGGLE_WINDOW (widget)->priv;
+
+	if (!(gdk_window_get_state (gtk_widget_get_window (widget)) & GDK_WINDOW_STATE_MAXIMIZED)) {
 		gtk_window_get_size (GTK_WINDOW (widget), &priv->width, &priv->height);
 		gtk_window_get_position (GTK_WINDOW (widget), &priv->x, &priv->y);
 	}
@@ -359,7 +371,9 @@ static void
 window_clipboard_changed_cb (GiggleClipboard *clipboard,
 			     GiggleWindow    *window)
 {
-	GiggleWindowPriv *priv = GET_PRIV (window);
+	GiggleWindowPriv *priv;
+
+	priv = window->priv;
 
 	if (!priv->ui_manager)
 		return;
@@ -394,11 +408,13 @@ static void
 window_set_focus (GtkWindow *window,
 		  GtkWidget *widget)
 {
-	GiggleWindowPriv *priv = GET_PRIV (window);
+	GiggleWindowPriv *priv;
 	gpointer          clipboard_proxy;
 	GiggleClipboard  *clipboard;
 	GtkTextBuffer    *buffer;
 
+	priv = GIGGLE_WINDOW (window)->priv;
+
 	clipboard_proxy = gtk_window_get_focus (window);
 
 	if (GTK_IS_TEXT_VIEW (clipboard_proxy))
@@ -537,7 +553,7 @@ window_create_menu (GiggleWindow *window)
 	GtkActionGroup   *action_group;
 	GError           *error = NULL;
 
-	priv = GET_PRIV (window);
+	priv = window->priv;;
 
 
 #ifdef GDK_WINDOWING_QUARTZ
@@ -574,7 +590,7 @@ giggle_window_set_directory (GiggleWindow *window,
 	GiggleWindowPriv *priv;
 	GError           *error = NULL;
 
-	priv = GET_PRIV (window);
+	priv = window->priv;
 
 	if (!giggle_git_set_directory (priv->git, directory, &error)) {
 		GtkWidget *dialog;
@@ -603,9 +619,9 @@ window_bind_state (GiggleWindow *window)
 	gboolean	  maximized;
 	GtkAction 	 *show_graph_action;
 
-	priv = GET_PRIV (window);
+	priv = window->priv;
 
-	if (!GTK_WIDGET_VISIBLE (window)) {
+	if (!gtk_widget_get_visible (GTK_WIDGET (window))) {
 		geometry = giggle_git_config_get_field (priv->configuration,
 							GIGGLE_GIT_CONFIG_FIELD_MAIN_WINDOW_GEOMETRY);
 		maximized = giggle_git_config_get_boolean_field (priv->configuration,
@@ -665,7 +681,7 @@ window_action_open_cb (GtkAction    *action,
 	GtkWidget        *file_chooser;
 	gchar      	 *directory = NULL;
 
-	priv = GET_PRIV (window);
+	priv = window->priv;
 
 	file_chooser = gtk_file_chooser_dialog_new (
 		_("Select git repository"),
@@ -700,7 +716,7 @@ window_action_properties_cb (GtkAction    *action,
 	const gchar      *project_name;
 	GtkWidget	 *summary_view;
 
-	priv = GET_PRIV (window);
+	priv = window->priv;
 
 	if (!priv->summary_dialog) {
 		project_name = giggle_git_get_project_name (priv->git);
@@ -713,9 +729,9 @@ window_action_properties_cb (GtkAction    *action,
 
 		summary_view = giggle_view_summary_new ();
 
-		gtk_box_pack_start_defaults
-			(GTK_BOX (GTK_DIALOG (priv->summary_dialog)->vbox),
-			 summary_view);
+		gtk_box_pack_start
+			(GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (priv->summary_dialog))),
+			 summary_view, TRUE, TRUE, 0);
 
 		gtk_window_set_default_size
 			(GTK_WINDOW (priv->summary_dialog), 460, 400);
@@ -787,7 +803,7 @@ window_find (EggFindBar            *find_bar,
 	const gchar      *search_string;
 	gboolean          full_search;
 
-	priv = GET_PRIV (window);
+	priv = window->priv;
 
 	view = giggle_view_shell_get_selected (GIGGLE_VIEW_SHELL (priv->view_shell));
 
@@ -824,7 +840,7 @@ window_action_find_cb (GtkAction    *action,
 {
 	GiggleWindowPriv *priv;
 
-	priv = GET_PRIV (window);
+	priv = window->priv;
 
 	gtk_widget_show (priv->find_bar);
 	gtk_widget_grab_focus (priv->find_bar);
@@ -834,14 +850,14 @@ static void
 window_action_find_next_cb (GtkAction    *action,
 			    GiggleWindow *window)
 {
-	window_find_next (EGG_FIND_BAR (GET_PRIV (window)->find_bar), window);
+	window_find_next (EGG_FIND_BAR (window->priv->find_bar), window);
 }
 
 static void
 window_action_find_prev_cb (GtkAction    *action,
 			    GiggleWindow *window)
 {
-	window_find_previous (EGG_FIND_BAR (GET_PRIV (window)->find_bar), window);
+	window_find_previous (EGG_FIND_BAR (window->priv->find_bar), window);
 }
 
 static void
@@ -851,7 +867,7 @@ window_action_view_graph_cb (GtkAction    *action,
 	GiggleWindowPriv *priv;
 	gboolean          active;
 
-	priv = GET_PRIV (window);
+	priv = window->priv;
 
 	active = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action));
 	giggle_view_file_set_graph_visible (GIGGLE_VIEW_FILE (priv->file_view), active);
@@ -865,7 +881,8 @@ window_action_refresh_history (GtkAction    *action,
 	GiggleWindowPriv *priv;
 	const gchar      *directory;
 
-	priv = GET_PRIV (window);
+	priv = window->priv;
+
 	directory = giggle_git_get_directory (priv->git);
 	giggle_window_set_directory (window, directory);
 }
@@ -887,13 +904,6 @@ window_visit_uri (GiggleWindow *window,
 	g_object_unref (context);
 }
 
-static void
-window_action_homepage_cb (GtkAction    *action,
-			   GiggleWindow *window)
-{
-	window_visit_uri (window, PACKAGE_WEBSITE);
-}
-
 static void
 window_action_bug_report_cb (GtkAction    *action,
 			     GiggleWindow *window)
@@ -905,26 +915,84 @@ static void
 window_action_about_cb (GtkAction    *action,
 			GiggleWindow *window)
 {
+	gchar *license_translated;
+
+	const char *artists[] = {
+		"Andreas Nilsson",
+		NULL
+	};
+
 	const gchar *authors[] = {
 		"Carlos Garnacho",
 		"Mathias Hasselmann",
 		"Mikael Hallendal",
 		"Richard Hult",
 		"Sven Herzberg",
+		"",
+		_("Contributors:"),
+		"Javier Jardón",
+		"Łukasz Jernaś",
+		"Guilhem Bonnefille",
+		"Florian Müllner",
 		NULL
 	};
 
+	/*
+	const gchar *documenters[] = {
+		NULL
+	};
+	*/
+
+	const gchar *copyright = _("Copyright © 2007 - 2008 Imendio AB\n"
+	                           "Copyright © 2008 - 2009 Mathias Hasselmann\n"
+	                           "Copyright © 2009 - 2010 The Giggle authors");
+
+	const gchar *license[] = {
+		N_("This program is free software; you can redistribute it and/or modify "
+		   "it under the terms of the GNU General Public License as published by "
+		   "the Free Software Foundation; either version 2 of the License, or "
+		   "(at your option) any later version."),
+		N_("This program is distributed in the hope that it will be useful, "
+		   "but WITHOUT ANY WARRANTY; without even the implied warranty of "
+		   "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the "
+		   "GNU General Public License for more details."),
+		N_("You should have received a copy of the GNU General Public License "
+		   "along with this program; if not, write to the Free Software Foundation, Inc., "
+		   "51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA")
+	};
+	license_translated = g_strjoin ("\n\n",
+	                                _(license[0]),
+	                                _(license[1]),
+	                                _(license[2]),
+	                                NULL);
+
+	/* Translators: This is a special message that shouldn't be translated
+         * literally. It is used in the about box to give credits to
+         * the translators.
+         * Thus, you should translate it to your name and email address.
+         * You should also include other translators who have contributed to
+         * this translation; in that case, please write each of them on a separate
+         * line seperated by newlines (\n).
+         */
+	const gchar *translators = _("translator-credits");
+
 	gtk_show_about_dialog (GTK_WINDOW (window),
-			       "copyright",
-			       "Copyright \xc2\xa9 2007-2008 Imendio AB\n"
-			       "Copyright \xc2\xa9 2008 Mathias Hasselmann",
-			       "translator-credits", _("translator-credits"),
-			       "comments", _("A graphical frontend to the git directory tracker."),
-			       "website", PACKAGE_WEBSITE,
-			       "logo-icon-name", PACKAGE,
-			       "version", VERSION,
-			       "authors", authors,
+	                       "artists", artists,
+	                       "authors", authors,
+	                       "comments", _("A graphical frontend for Git"),
+			       "copyright", copyright,
+	                       /* "documenters", documenters, */
+	                       "license", license_translated,
+	                       "logo-icon-name", PACKAGE,
+	                       "title", _("About Giggle"),
+			       "translator-credits", translators,
+	                       "version", VERSION,
+			       "website", PACKAGE_URL,
+	                       "website-label", _("Giggle Website"),
+	                       "wrap-license", TRUE,
 			       NULL);
+
+	g_free (license_translated);
 }
 
 static void
@@ -934,7 +1002,7 @@ window_add_widget_cb (GtkUIManager *merge,
 {
 	GiggleWindowPriv *priv;
 
-	priv = GET_PRIV (window);
+	priv = window->priv;
 
 	if (GTK_IS_TOOLBAR (widget))
 		gtk_toolbar_set_show_arrow (GTK_TOOLBAR (widget), FALSE);
@@ -948,7 +1016,9 @@ static void
 window_action_history_go_back (GtkAction    *action,
 			       GiggleWindow *window)
 {
-	GiggleWindowPriv *priv = GET_PRIV (window);
+	GiggleWindowPriv *priv;
+
+	priv = window->priv;
 
 	g_return_if_fail (priv->history);
 	g_return_if_fail (priv->history->prev);
@@ -961,7 +1031,9 @@ static void
 window_action_history_go_forward (GtkAction    *action,
 				  GiggleWindow *window)
 {
-	GiggleWindowPriv *priv = GET_PRIV (window);
+	GiggleWindowPriv *priv;
+
+	priv = window->priv;
 
 	g_return_if_fail (priv->history);
 	g_return_if_fail (priv->history->next);
@@ -1030,7 +1102,6 @@ window_create_ui_manager (GiggleWindow *window)
 		  G_CALLBACK (window_action_delete_cb)
 		},
 
-		/* Toolbar items */
 		{ "HistoryGoBack", GTK_STOCK_GO_BACK, NULL,
 		  "<alt>Left", N_("Go backward in history"),
 		  G_CALLBACK (window_action_history_go_back)
@@ -1040,10 +1111,6 @@ window_create_ui_manager (GiggleWindow *window)
 		  G_CALLBACK (window_action_history_go_forward)
 		},
 
-		{ "Homepage", GTK_STOCK_HOME, N_("Visit _Homepage"),
-		  NULL, N_("Visit the homepage of Giggle"),
-		  G_CALLBACK (window_action_homepage_cb)
-		},
 		{ "BugReport", NULL, N_("Report _Issue"),
 		  NULL, N_("Report an issue you've found in Giggle"),
 		  G_CALLBACK (window_action_bug_report_cb)
@@ -1116,7 +1183,6 @@ window_create_ui_manager (GiggleWindow *window)
 		"      <menuitem action='HistoryGoForward'/>"
 		"    </menu>"
 		"    <menu action='HelpMenu'>"
-		"      <menuitem action='Homepage'/>"
 		"      <menuitem action='BugReport'/>"
 		"      <separator/>"
 		"      <menuitem action='About'/>"
@@ -1148,7 +1214,7 @@ window_create_ui_manager (GiggleWindow *window)
 	GtkActionGroup   *action_group;
 	GError           *error = NULL;
 
-	priv = GET_PRIV (window);
+	priv = window->priv;
 
 	priv->ui_manager = gtk_ui_manager_new ();
 
@@ -1209,11 +1275,8 @@ static void
 window_recent_repository_activate (GtkAction    *action,
 				   GiggleWindow *window)
 {
-	GiggleWindowPriv *priv;
 	const gchar      *directory;
 
-	priv = GET_PRIV (window);
-
 	directory = g_object_get_data (G_OBJECT (action), "recent-action-path");
 	giggle_window_set_directory (window, directory);
 }
@@ -1229,7 +1292,7 @@ window_recent_connect_proxy_cb (GtkActionGroup *action_group,
 	if (!GTK_IS_MENU_ITEM (proxy))
 		return;
 
-	label = GTK_LABEL (GTK_BIN (proxy)->child);
+	label = GTK_LABEL (gtk_bin_get_child (GTK_BIN (proxy)));
 
 	gtk_label_set_ellipsize (label, PANGO_ELLIPSIZE_MIDDLE);
 	gtk_label_set_max_width_chars (label, RECENT_ITEM_MAX_N_CHARS);
@@ -1261,7 +1324,7 @@ window_compare_recent_info (gconstpointer a,
 static void
 window_recent_repositories_update (GiggleWindow *window)
 {
-	GiggleWindowPriv *priv = GET_PRIV (window);
+	GiggleWindowPriv *priv;
 	GList            *recent_items, *l;
 	GtkRecentInfo    *info;
 	GtkAction        *action;
@@ -1270,6 +1333,8 @@ window_recent_repositories_update (GiggleWindow *window)
 	GString          *action_label;
 	gint              count = 0;
 
+	priv = window->priv;
+
 	if (priv->recent_merge_id != 0) {
 		gtk_ui_manager_remove_ui (priv->ui_manager, priv->recent_merge_id);
 		priv->recent_merge_id = 0;
@@ -1298,7 +1363,7 @@ window_recent_repositories_update (GiggleWindow *window)
 	for (l = recent_items; l && count < MAX_N_RECENT; l = l->next) {
 		info = l->data;
 
-		if (gtk_recent_info_has_group (info, RECENT_FILES_GROUP)) {
+		if (gtk_recent_info_has_group (info, PACKAGE)) {
 			if (!gtk_recent_info_exists (info))
 				continue;
 
@@ -1352,7 +1417,7 @@ window_create_recent_manager (GiggleWindow *window)
 {
 	GiggleWindowPriv *priv;
 
-	priv = GET_PRIV (window);
+	priv = window->priv;
 
 	priv->recent_action_group = gtk_action_group_new ("RecentRepositories");
 	priv->recent_manager = gtk_recent_manager_get_default ();
@@ -1373,7 +1438,7 @@ window_cancel_find (GtkWidget    *widget,
 	GiggleWindowPriv *priv;
 	GiggleView       *view;
 
-	priv = GET_PRIV (window);
+	priv = window->priv;
 
 	view = giggle_view_shell_get_selected (GIGGLE_VIEW_SHELL (priv->view_shell));
 	g_return_if_fail (GIGGLE_IS_SEARCHABLE (view));
@@ -1389,7 +1454,7 @@ window_create_find_bar (GiggleWindow *window)
 	GiggleWindowPriv *priv;
 	GtkToolItem      *separator;
 
-	priv = GET_PRIV (window);
+	priv = window->priv;
 
 	priv->find_bar = egg_find_bar_new ();
 
@@ -1418,12 +1483,14 @@ window_create_find_bar (GiggleWindow *window)
 static void
 window_update_search_ui (GiggleWindow *window)
 {
-	GiggleWindowPriv *priv = GET_PRIV (window);
+	GiggleWindowPriv *priv;
 	gboolean          searchable = FALSE;
 	GtkActionGroup   *action_group;
 	GiggleView       *view;
 
-	if (GTK_WIDGET_VISIBLE (priv->view_shell)) {
+	priv = window->priv;
+
+	if (gtk_widget_get_visible (priv->view_shell)) {
 		view = giggle_view_shell_get_selected (GIGGLE_VIEW_SHELL (priv->view_shell));
 		searchable = GIGGLE_IS_SEARCHABLE (view);
 	}
@@ -1450,9 +1517,11 @@ static void
 window_history_changed_cb (GiggleHistory *history,
 			   GiggleWindow  *window)
 {
-	GiggleWindowPriv *priv = GET_PRIV (window);
+	GiggleWindowPriv *priv;
 	GiggleView       *view;
 
+	priv = window->priv;
+
 	view = giggle_view_shell_get_selected (GIGGLE_VIEW_SHELL (priv->view_shell));
 
 	if (GIGGLE_IS_HISTORY (view) && GIGGLE_HISTORY (view) == history)
@@ -1493,11 +1562,13 @@ window_directory_changed_cb (GiggleGit    *git,
 			     GParamSpec   *arg,
 			     GiggleWindow *window)
 {
-	GiggleWindowPriv *priv = GET_PRIV (window);
+	GiggleWindowPriv *priv;
 	gchar            *title;
 	const gchar      *directory;
 	GtkActionGroup   *action_group;
 
+	priv = window->priv;
+
 	directory = giggle_git_get_directory (git);
 	title = g_strdup_printf ("%s - %s", directory, g_get_application_name ());
 	gtk_window_set_title (GTK_WINDOW (window), title);
@@ -1513,13 +1584,13 @@ window_directory_changed_cb (GiggleGit    *git,
 static void
 window_recent_repositories_add (GiggleWindow *window)
 {
-	static gchar     *groups[] = { RECENT_FILES_GROUP, NULL };
+	static gchar     *groups[] = { PACKAGE, NULL };
 	GiggleWindowPriv *priv;
 	GtkRecentData     data = { 0, };
 	const gchar      *repository;
 	gchar            *tmp_string;
 
-	priv = GET_PRIV (window);
+	priv = window->priv;
 
 	repository = giggle_git_get_project_dir (priv->git);
 
@@ -1547,12 +1618,16 @@ window_plugin_added_cb (GigglePluginManager *manager,
 			GigglePlugin        *plugin,
 			GiggleWindow        *window)
 {
-	GiggleWindowPriv *priv = GET_PRIV (window);
+	GiggleWindowPriv *priv;
 	GError           *error = NULL;
 
+	priv = window->priv;
+
+	/*
 	g_print ("%s: %s - %s\n", G_STRFUNC,
 		 giggle_plugin_get_filename (plugin),
 		 giggle_plugin_get_description (plugin));
+	*/
 
 	if (!giggle_plugin_merge_ui (plugin, priv->ui_manager, &error)) {
 		g_warning ("%s: %s", G_STRFUNC, error->message);
@@ -1581,7 +1656,12 @@ button_activate_link (GtkLinkButton *button,
 static void
 giggle_window_init (GiggleWindow *window)
 {
-	GiggleWindowPriv *priv = GET_PRIV (window);
+	GiggleWindowPriv *priv;
+
+	window->priv = G_TYPE_INSTANCE_GET_PRIVATE (window,
+	                                            GIGGLE_TYPE_WINDOW,
+	                                            GiggleWindowPriv);
+	priv = window->priv;
 
 	priv->git = giggle_git_get ();
 	priv->configuration = giggle_git_config_new ();
@@ -1591,6 +1671,7 @@ giggle_window_init (GiggleWindow *window)
 
 	priv->view_shell = giggle_view_shell_new_with_ui (priv->ui_manager,
 							  "WindowViewShellActions");
+
 	priv->history_view = giggle_view_history_new (priv->ui_manager);
 	priv->file_view = giggle_view_file_new ();
 
@@ -1617,8 +1698,8 @@ giggle_window_init (GiggleWindow *window)
 	giggle_view_shell_append_view (GIGGLE_VIEW_SHELL (priv->view_shell),
 				       GIGGLE_VIEW (priv->history_view));
 
-	gtk_box_pack_start_defaults (GTK_BOX (priv->content_vbox),
-				     priv->view_shell);
+	gtk_box_pack_start (GTK_BOX (priv->content_vbox),
+	                    priv->view_shell, TRUE, TRUE, 0);
 
 	gtk_container_add (GTK_CONTAINER (window), priv->content_vbox);
 	gtk_widget_show_all (priv->content_vbox);
@@ -1635,6 +1716,9 @@ giggle_window_init (GiggleWindow *window)
 
 	priv->plugin_manager = giggle_plugin_manager_new ();
 
+	giggle_plugin_manager_add_widget (priv->plugin_manager,
+					  "ViewShell", priv->view_shell);
+
 	g_signal_connect (priv->plugin_manager, "plugin-added",
 			  G_CALLBACK (window_plugin_added_cb), window);
 
@@ -1663,7 +1747,7 @@ window_action_save_patch_cb (GtkAction    *action,
 	gchar            *text, *path;
 	GError           *error = NULL;
 
-	priv = GET_PRIV (window);
+	priv = window->priv;
 
 	file_chooser = gtk_file_chooser_dialog_new (
 		_("Save patch file"),
@@ -1719,7 +1803,7 @@ giggle_window_get_git (GiggleWindow *self)
 {
 	g_return_val_if_fail (GIGGLE_IS_WINDOW (self), NULL);
 
-	return GET_PRIV (self)->git;
+	return self->priv->git;
 }
 
 void
